import sys, os, shutil, codecs
sys.path.append( os.path.expandvars( '${HOME}/versavant'))
import versavant
from messaging import dbgMsg, errMsg, stdMsg

copyrightNotice = u''

#######################################################
def main():

    global vsv

    inputFile = ''
    outputFile = ''
    codeFile = ''
    functionName = ''
    taskName = ''
    taskDesc = ''
    argString = ''
    doInspect = 'yes'
    vsvCacheDir = None  ## by default, use Versavant's default cache directory
    forceLoadTMAs = 'no'

    argCtr = 0
    while argCtr < len( sys.argv):
        if argCtr == 0:
            scriptName = sys.argv[ argCtr]
        elif sys.argv[ argCtr] == '':
            pass  ## ignore empty arguments; makes the makefile easier to write
        elif sys.argv[ argCtr] == 'inspect':  ## run vsv.inspect() at end, 'yes' or 'no'
            argCtr += 1
            doInspect = sys.argv[ argCtr].lower()
            if not ( doInspect == 'yes' or doInspect == 'no'):
                print 'unrecognized \'inspect\' argument: "%s"; must be yes or no.' % ( doInspect)
                sys.exit( 1)
        elif sys.argv[ argCtr] == 'forceLoadTMAs':
            argCtr += 1
            forceLoadTMAs = sys.argv[ argCtr].lower()
            if not ( forceLoadTMAs == 'yes' or forceLoadTMAs == 'no'):
                print 'unrecognized \'forceLoadTMAs\' argument: "%s"; must be yes or no.' % ( forceLoadTMAs)
                sys.exit( 1)
        elif sys.argv[ argCtr] == 'inputFile':  ## input file name
            argCtr += 1
            inputFile = sys.argv[ argCtr]
        elif sys.argv[ argCtr] == 'outputFile':  ## output file name
            argCtr += 1
            outputFile = sys.argv[ argCtr]
        elif sys.argv[ argCtr] == 'codeFile':  ## task code file
            argCtr += 1
            codeFile = sys.argv[ argCtr]
        elif sys.argv[ argCtr] == 'functionName':  ## function name in task code file
            argCtr += 1
            functionName = sys.argv[ argCtr]
        elif sys.argv[ argCtr] == 'taskName':  ## task name
            argCtr += 1
            taskName = sys.argv[ argCtr]
        elif sys.argv[ argCtr] == 'taskDesc':  ## task description
            argCtr += 1
            taskDesc = sys.argv[ argCtr]
        elif sys.argv[ argCtr] == 'argString':  ## args to task func (exec-ed)
            argCtr += 1
            argString = sys.argv[ argCtr]
        elif sys.argv[ argCtr] == 'vsvCacheDir':  ## where Versavant should put its cache of loaded TMAs
            argCtr += 1
            vsvCacheDir = sys.argv[ argCtr]
        elif not sys.argv[ argCtr].startswith( '-'):
            print 'unrecognized parameter: %s' % ( sys.argv[ argCtr])
            sys.exit( 1)
        else:
            for charCtr in range( len( sys.argv[ argCtr])):
                if charCtr == 0:
                    pass
##                 elif sys.argv[ argCtr][ charCtr] == 'm':  ## Makefile-driven execution; don't stop
##                     doInspect = 'no'
                else:
                    print 'unrecognized parameter character: "%s" in "%s"' % ( sys.argv[ argCtr][ charCtr], sys.argv[ argCtr])
                    sys.exit( 1)
        argCtr += 1

    vsv = versavant.Versavant( vsvCacheDir, suppressLicenseMessage=True)
    topicMap = vsv.newTopicMap( os.environ[ 'SUBJECTMAPNAME'], 'dictionary of EMAIL words, with tables')


    if inputFile == '' or forceLoadTMAs == 'yes':  ## Need to load the TMAs

        vsv.loadTMA( os.environ[ 'SUBJECTMAPNAME'], 'uod1',  os.path.expandvars('%s/uod1.xml' % ( os.environ[ 'EMAILUODDIRPATH'])))
        vsv.loadTMA( os.environ[ 'SUBJECTMAPNAME'], 'uod2',  os.path.expandvars('%s/uod2.xml' % ( os.environ[ 'EMAILUODDIRPATH'])))

    if inputFile != '':
        vsv.importXMLTopicMap( os.environ[ 'SUBJECTMAPNAME'], inputFile, 'reimport')

    if argString == '':
        origPTask = vsv.registerOriginalPopulationTask(
            os.environ[ 'SUBJECTMAPNAME'],  ## SM name
            codeFile,   ## File
            functionName,  ## function
            taskName,  ## name of task
            taskDesc ## description
            )
    else:
        origPTask = vsv.registerOriginalPopulationTask(
            os.environ[ 'SUBJECTMAPNAME'],  ## SM name
            codeFile,   ## File
            functionName,  ## function
            taskName,  ## name of task
            taskDesc, ## description
            argString  ## arg string to be exec'ed
            )

    vsv.populate( origPTask)

    vsv.merge( os.environ[ 'SUBJECTMAPNAME'])

    if outputFile != '':
        vsv.exportXMLTopicMap( os.environ[ 'SUBJECTMAPNAME'], outputFile, legalNotice=copyrightNotice)

    if doInspect == 'yes':
        vsv.inspect( topicMapName=os.environ[ 'SUBJECTMAPNAME'], showProxies='liveNonSystem')

if __name__ == '__main__':
    main()


